# noqa: INP001
"""Generate pages to forward workflow URLs.

This will redirect `/workflow/workflow_name` to `reference/gso/workflow/module/workflow_name`. This is required since
URLs cannot be changed in the GUI.
"""

from pathlib import Path

import yaml

root = Path(__file__).parent.parent.parent
src = root / "gso"
redirect_map = {}

for path in sorted(src.rglob("*.py")):
    module_path = path.relative_to(root).with_suffix("")
    parts = tuple(module_path.parts)

    if parts[-1] == "__init__":
        parts = parts[:-1]
    elif parts[-1] == "__main__":
        continue

    if len(parts) == 4 and "workflows" in parts:  # noqa: PLR2004
        redirect_map["workflow/" + parts[3] + "/index.md"] = "https://docs.gap.geant.org/reference/" + "/".join(parts)

with Path.open(root / "docs" / "wf_redirects.yaml", "w") as redirect_file:
    file_content = {
        "plugins": [
            "search",
            {"gen-files": {"scripts": ["scripts/gen_ref_pages.py"]}},
            {"redirects": {"redirect_maps": redirect_map}},
            {"literate-nav": {"nav_file": "SUMMARY.md"}},
            "mkdocstrings",
        ]
    }
    yaml.dump(file_content, redirect_file)
