# Sites

Sites are an abstract construction to model information that is shared across
all services deployed at one physical location. They only contain information
relevant to the services that rely on it. As a result, external BSS and OSS 
systems are still in place for other accounting and bookkeeping purposes. 
However, these lie outside the scope of GAP.

## Modelling and attributes

A Site object contains the following attributes:

| Attribute name                                   | Attribute type                                | Description                                                                                                                                                                      |
|--------------------------------------------------|-----------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| `site_name`                                      | `str`                                         | The name of the site, that will dictate part of the FQDN of routers that are hosted at this site.<br/>For example: `router.X.Y.geant.net`, where X denotes the name of the site. |
| `site_city`                                      | `str`                                         | The city at which the site is located.                                                                                                                                           |
| `site_country`                                   | `str`                                         | The country in which the site is located.                                                                                                                                        |
| `site_country_code`                              | `str`                                         | The code of the corresponding country. This is also used for the FQDN,<br/>following the example for the site name, the country code goes in the Y position.                     |
| `site_latitude`                                  | `LatitudeCoordinate`                          | The latitude of the site, used for SNMP.                                                                                                                                         |
| `site_longitude`                                 | `LongitudeCoordinate`&nbsp;&nbsp;&nbsp;&nbsp; | The longitude of the site, again for SNMP.                                                                                                                                       |
| `site_internal_id`                               | `int`                                         | The internal ID used within GÉANT for a site.                                                                                                                                    |
| `site_bgp_community_id` &nbsp;&nbsp;&nbsp;&nbsp; | `int`                                         | The BGP community ID of a site, used to advertise routes learned at this site.                                                                                                   |
| `site_tier`                                      | `SiteTier`                                    | The tier of a site, which corresponds to installed equipment.                                                                                                                    |
| `site_ts_address`                                | `IPv4Address`                                 | The address of the terminal server hosted at this site.<br/>It is used for out of band access to any equipment hosted here.                                                      |
