"""A modification workflow for migrating an ImportedSuperPoPSwitch to a SuperPopSwitch subscription."""

from orchestrator.targets import Target
from orchestrator.types import State, UUIDstr
from orchestrator.workflow import StepList, done, init, step, workflow
from orchestrator.workflows.steps import resync, store_process_subscription, unsync
from orchestrator.workflows.utils import wrap_modify_initial_input_form

from gso.products import ProductName
from gso.products.product_types.super_pop_switch import ImportedSuperPopSwitch, SuperPopSwitch
from gso.services.subscriptions import get_product_id_by_name


@step("Create new super_pop_switch subscription")
def import_super_pop_switch_subscription(subscription_id: UUIDstr) -> State:
    """Take an ImportedSuperPopSwitch subscription, and turn it into a SuperPopSwitch subscription."""
    old_super_pop_switch = ImportedSuperPopSwitch.from_subscription(subscription_id)
    new_subscription_id = get_product_id_by_name(ProductName.SUPER_POP_SWITCH)
    new_subscription = SuperPopSwitch.from_other_product(old_super_pop_switch, new_subscription_id)  # type: ignore[arg-type]

    return {"subscription": new_subscription}


@workflow("Import SuperPopSwitch", target=Target.MODIFY, initial_input_form=wrap_modify_initial_input_form(None))
def import_super_pop_switch() -> StepList:
    """Modify an ImportedSuperPopSwitch subscription into a SuperPopSwitch subscription to complete the import."""
    return (
        init
        >> store_process_subscription(Target.MODIFY)
        >> unsync
        >> import_super_pop_switch_subscription
        >> resync
        >> done
    )
