import pytest

from gso.products.product_types.l3_core_service import L3CoreService, L3CoreServiceType
from test.workflows import assert_complete, extract_state, run_workflow


@pytest.mark.parametrize(
    "l3_core_service_type",
    [
        L3CoreServiceType.GEANT_IP,
        L3CoreServiceType.IAS,
        L3CoreServiceType.GWS,
        L3CoreServiceType.LHCONE,
        L3CoreServiceType.COPERNICUS,
    ],
)
@pytest.mark.workflow()
def test_migrate_l3_core_service_success(
    faker,
    edge_port_subscription_factory,
    partner_factory,
    l3_core_service_subscription_factory,
    l3_core_service_type,
):
    partner = partner_factory()
    subscription_id = l3_core_service_subscription_factory(partner=partner, l3_core_service_type=l3_core_service_type)
    new_edge_port_1 = edge_port_subscription_factory(partner=partner)
    new_edge_port_2 = edge_port_subscription_factory(partner=partner)
    subscription = L3CoreService.from_subscription(subscription_id)

    form_input_data = [
        {"subscription_id": subscription_id},
        {
            "tt_number": faker.tt_number(),
            "edge_port_selection": [
                {
                    "old_edge_port": subscription.l3_core_service.ap_list[0].sbp.edge_port.description,
                    "new_edge_port": new_edge_port_1,
                },
                {
                    "old_edge_port": subscription.l3_core_service.ap_list[1].sbp.edge_port.description,
                    "new_edge_port": new_edge_port_2,
                },
            ],
        },
    ]

    result, _, _ = run_workflow("migrate_l3_core_service", form_input_data)

    assert_complete(result)
    state = extract_state(result)
    subscription = L3CoreService.from_subscription(state["subscription_id"])
    assert subscription.insync is True
    assert len(subscription.l3_core_service.ap_list) == 2
    assert str(subscription.l3_core_service.ap_list[0].sbp.edge_port.owner_subscription_id) == new_edge_port_1
    assert str(subscription.l3_core_service.ap_list[1].sbp.edge_port.owner_subscription_id) == new_edge_port_2
